let targets pubdir = List.fold_left
	(fun a x ->
		let path = Filename.concat pubdir (snd x) in
		try if Sys.is_directory path then (fst x, path)::a else a with Sys_error _ -> a)
	[]
	["htm,atom", "public_html/"; "gmi,gmi-atom", "public_gemini/"; "", "public_gopher/"]

open Logarion
let publish pubdir ids =
	let kv = Logarion.File_store.of_kv_file () in
	let predicate t = List.mem t.Text.id ids in
	let pubdir = match pubdir with Some d -> d | None ->
		try Logarion.Store.KV.find "Pubdir" kv with Not_found ->
		try Sys.getenv "txtpubdir" with Not_found -> ""
	in
	let targets = targets pubdir in
	if targets = [] then
		Printf.eprintf "No target directories in $pubdir='%s'\n" pubdir
	else begin
		let pub_dirs = List.map (fun x -> snd x) targets in
		File_store.iter ~predicate (fun (_t, p) ->
			try File.file ((List.hd p)::pub_dirs)
			with Unix.Unix_error (Unix.EEXIST, _, _) -> ());
		List.iter (fun t -> Printf.eprintf "%s %s\n" (fst t) (snd t);
			Index.((load (snd t)) false None None None None);
			Convert.at_path (fst t) false (snd t))
			targets
	end

open Cmdliner
let term =
	let ids = Arg.(value & pos_all string [] & info [] ~docv:"text ids") in
	let pubdir = Arg.(value & opt (some string) None & info ["p"; "pubdir"] ~docv:"directory path"
		~doc:"set top directory for publishing files") in
	let doc = "convert texts into standard public dirs pubdir/public_{html,gemini,gopher} if they exist" in
	Term.(const publish $ pubdir $ ids), Term.info "publish" ~doc ~man:[ `S "DESCRIPTION"; `P doc ]
